@@ -1,10 +1,10 @@
 # pylint: disable-msg=W0622
 """cubicweb-vcsfile packaging information"""
 
-distname = "cubicweb-vcsfile"
-modname = distname.split('-', 1)[1]
+modname = 'vcsfile'
+distname = "cubicweb-%s" % modname
 
-numversion = (1, 0, 6)
+numversion = (1, 0, 7)
 version = '.'.join(str(num) for num in numversion)
 
 copyright = '''Copyright (c) 2007-2009 LOGILAB S.A. (Paris, FRANCE).
@@ -13,16 +13,14 @@ http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
 license = 'LGPL'
 author = "Logilab"
 author_email = "contact@logilab.fr"
-web = 'http://www.cubicweb.org/project/%s' % modname
+web = 'http://www.cubicweb.org/project/%s' % distname
 
-short_desc = "Interface local versioned files repository content as cubicweb entities"
-long_desc = """Cubicweb is a entities / relations bases knowledge management system
-developped at Logilab.
-.
-This package provides a custom source as well as custom entity types and
-views to provide transparent access of files versioned in subversion or
-mercurial repositories.
-.
+short_desc = "component to use version control systems from the CubicWeb framework"
+long_desc = """CubicWeb VCSFile component to integrate with version control systems and
+make their data available from within a CubicWeb application (currently
+works for mercurial and subversion).
+
+CubicWeb is a semantic web application framework, see http://www.cubicweb.org
 """
 
 from os import listdir as _listdir
@@ -50,10 +48,15 @@ for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18
 
 cube_eid = None # XXX
 # used packages
-__use__ = ()
+__depends_cubes__ = {}
+__depends__ = {'cubicweb': '>= 3.3.1',
+               'logilab-mtconverter': '>= 0.5.0',
+               'pysqlite': None,
+               }
+__use__ = tuple(__depends_cubes__)
 classifiers = [
            'Environment :: Web Environment',
            'Framework :: CubicWeb',
            'Programming Language :: Python',
            'Programming Language :: JavaScript',
-]
+           ]
