@@ -51,7 +51,6 @@ def cache_handler_for_repository(repoent):
         pass
     repohdlr = build_repository_handler(repoent.eid, repoent.type, repoent.path,
                                         repoent.encoding, repoent.req._)
-
     _REPOHDLRS[repoent.eid] = repohdlr
     return repohdlr
 
@@ -70,7 +69,7 @@ def build_repository_handler(eid, type, path, encoding, _=unicode):
     return repohdlr
 
 
-def import_content(repo):
+def import_content(repo, commitevery=10):
     """synchronize content of known vcs repositories
 
     `repo` is the cubicweb repository (not a vcs repository)
@@ -81,13 +80,23 @@ def import_content(repo):
             'Any X, T, P, SP, E, LR '
             'WHERE X is Repository, X type T, X path P, X subpath SP,'
             'X encoding E, X latest_known_revision LR').entities():
+            # give a change to threads waiting for a pool
+            session.set_pool()
             try:
                 repohdlr = cache_handler_for_repository(repoentity)
             except VCSException, ex:
                 repo.error(str(ex))
                 continue
-            repohdlr.import_content(repoentity)
-        session.commit()
+            try:
+                repohdlr.import_content(repoentity, commitevery)
+                session.commit()
+            except:
+                import traceback
+                traceback.print_exc()
+                repoentity.exception(
+                    'error while importing content for vcs repo %s',
+                    repoentity.dc_title())
+                session.rollback()
     finally:
         session.close()
 
