@@ -39,10 +39,6 @@ class ServerStartupHook(Hook):
     """
     events = ('server_startup',)
     def call(self, repo):
-        try:
-            bridge.import_content(repo)
-        except:
-            self.exception('error while trying to import vcs content')
         repo.system_source.map_attribute('VersionContent', 'data',
                                          _generate_vc_data)
         repo.looping_task(repo.config.get('check-revision-interval', 5*60),
@@ -238,9 +234,11 @@ class AddParentRevisionHook(Hook):
     def call(self, session, fromeid, rtype, toeid):
         session.repo.glob_add_relation(session,
                                        fromeid, 'ancestor_revision', toeid)
+        # need NOT safety belt in case of merge nodes with two parents
         session.unsafe_execute(
             'SET R ancestor_revision AR '
-            'WHERE R eid %(rev)s, PR eid %(prev)s, PR ancestor_revision AR',
+            'WHERE R eid %(rev)s, PR eid %(prev)s, PR ancestor_revision AR, '
+            'NOT R ancestor_revision AR',
             {'rev': fromeid, 'prev': toeid}, 'rev')
 
 
